@@ -3,6 +3,7 @@ use strict;
 use warnings;
 use HTML::TreeBuilder::XPath 0.14;
 use Exporter 'import';
+use Carp 'croak';
 
 our @EXPORT_OK = (
     'find_next_id',       'find_errors',
@@ -16,7 +17,7 @@ my %regexes = (
     http_500   => qr/500/,
 );
 
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 =head1 NAME
 
@@ -47,6 +48,8 @@ Returns the ID if found, otherwise C<undef>.
 # TODO: use XPath instead of regex
 sub find_next_id {
     my $content_ref = shift;
+    croak "Must receive an scalar reference as parameter"
+        unless ( ref($content_ref) eq 'SCALAR' );
     my $next_id;
 
     if ( $$content_ref =~ $regexes{next_id} ) {
@@ -69,7 +72,9 @@ Returns an array reference with all warnings found.
 # TODO: create a single tree instance and check for everything at once
 sub find_warnings {
     my $content_ref = shift;
-    my $tree        = HTML::TreeBuilder::XPath->new;
+    croak "Must receive an scalar reference as parameter"
+        unless ( ref($content_ref) eq 'SCALAR' );
+    my $tree = HTML::TreeBuilder::XPath->new;
     $tree->parse_content($$content_ref);
     my @nodes
         = $tree->findnodes('//div[@id="content"]/div[@class="warning"]');
@@ -94,6 +99,8 @@ Returns an array reference with all errors found.
 
 sub find_errors {
     my $content_ref = shift;
+    croak "Must receive an scalar reference as parameter"
+        unless ( ref($content_ref) eq 'SCALAR' );
     my $tree        = HTML::TreeBuilder::XPath->new;
     $tree->parse_content($$content_ref);
     my @nodes = $tree->findnodes('//div[@id="content"]/div[@class="error"]');
@@ -121,6 +128,8 @@ Returns an array reference with all best contacts found.
 
 sub find_best_contacts {
     my $content_ref = shift;
+    croak "Must receive an scalar reference as parameter"
+        unless ( ref($content_ref) eq 'SCALAR' );
     my $tree        = HTML::TreeBuilder::XPath->new;
     $tree->parse_content($content_ref);
     my @nodes = $tree->findnodes('//div[@id="content"]');
@@ -193,6 +202,8 @@ Returns an array reference, where each item is a string.
 
 sub find_receivers {
     my $content_ref = shift;
+    croak "Must receive an scalar reference as parameter"
+        unless ( ref($content_ref) eq 'SCALAR' );
     my $tree        = HTML::TreeBuilder::XPath->new;
     $tree->parse_content($content_ref);
     my @nodes = $tree->findnodes('//*[@id="content"]');
